pub struct AgeStanza<'a> {
    pub tag: &'a str,
    pub args: Vec<&'a str>,
    /* private fields */
}
A section of the age header that encapsulates the file key as encrypted to a specific recipient.

This is the reference type; see Stanza for the owned type.

Fields

tag: &'a str

A tag identifying this stanza type.

args: Vec<&'a str>

Zero or more arguments.

Implementations

Decodes and returns the body of this stanza.