pub struct Stanza {
    pub tag: String,
    pub args: Vec<String>,
    pub body: Vec<u8>,
}
A section of the age header that encapsulates the file key as encrypted to a specific recipient.

This is the owned type; see AgeStanza for the reference type.

Fields

tag: String

A tag identifying this stanza type.

args: Vec<String>

Zero or more arguments.

body: Vec<u8>

The body of the stanza, containing a wrapped FileKey.