pub struct Connection<R: Read, W: Write> { /* private fields */ }
Available on crate feature plugin only.
A connection to a plugin binary.

Implementations

Starts a plugin binary with the given state machine.

If the AGEDEBUG environment variable is set to plugin, then all messages sent to and from the plugin, as well as anything the plugin prints to its stderr, will be printed to the stderr of the parent process.

Initialise a connection from an age client.

Runs a unidirectional phase as the controller.

Runs a unidirectional phase as the recipient.

Arguments

command_a, command_b, and (optionally) command_c are the known commands that are expected to be received. All other received commands (including grease) will be ignored.

Runs a bidirectional phase as the controller.

Runs a bidirectional phase as the recipient.