This is supported on crate feature plugin only.
The possible replies to a bidirectional command.
Reply with ok and optional data.
The command failed (for example, the user failed to respond to an input request).
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,