Crate age_core[−][src]
This crate contains common structs and functions used across the age crates.
You are probably looking for the age crate
itself. You should only need to directly depend on this crate if you are
implementing a custom recipient type.
Re-exports
pub use secrecy;Modules
Core types and encoding operations used by the age file format.
plugin
pluginCommon structs and constants for the age plugin system.
Primitive cryptographic operations used across various age components.