Module age_core::format [−][src]
Modules
| read | |
| write |
Structs
| AgeStanza | A section of the age header that encapsulates the file key as encrypted to a specific recipient. |
| FileKey | A file key for encrypting or decrypting an age file. |
| Stanza | A section of the age header that encapsulates the file key as encrypted to a specific recipient. |
Constants
| FILE_KEY_BYTES | The length of an age file key. |
Functions
| grease_the_joint | Creates a random recipient stanza that exercises the joint in the age v1 format. |