Available on crate feature
plugin only.Expand description
Common structs and constants for the age plugin system.
These are shared between the client implementation in the age crate, and the plugin
implementations built around the age-plugin crate.
Structs
Actions that a controller may take during a bidirectional phase.
A connection to a plugin binary.
The possible replies to a bidirectional command.
A response to a bidirectional command.
Actions that a controller may take during a unidirectional phase.
Enums
An error within the plugin protocol.
Constants
Type Definitions
Result type for the plugin protocol.