Struct age_core::plugin::Connection[][src]

pub struct Connection<R: Read, W: Write> { /* fields omitted */ }
This is supported on crate feature plugin only.
A connection to a plugin binary.

Implementations

Start a plugin binary with the given state machine.

Initialise a connection from an age client.

Runs a unidirectional phase as the controller.

Runs a unidirectional phase as the recipient.

Arguments

command_a, command_b, and (optionally) command_c are the known commands that are expected to be received. All other received commands (including grease) will be ignored.

Runs a bidirectional phase as the controller.

Runs a bidirectional phase as the recipient.